import { Injectable } from '@angular/core';
import { User } from '../user-item/user.model';
import { BehaviorSubject, Observable } from 'rxjs';
import { UserHttpService } from './user-http.service';


@Injectable({
  providedIn: 'root'
})
export class UserService {

  users = new BehaviorSubject<User[]>([]);
  selectedUser = new BehaviorSubject<User | null>(null); // Ajout de la propriété selectedUser

  constructor(private userHttp: UserHttpService) { }



  private loadUserInCache() {
    this.getUsers().subscribe(usersList => {
      this.users.next(usersList);
      console.debug("user loaded");
    })
  }

  getUsers(): Observable<User[]> {
    return this.userHttp.getUsers();
  }

  addUser(user: User) {
    this.userHttp.addUser(user).subscribe(ass => {
      this.loadUserInCache();
      console.info("add usersList");
    });

  }
  

  deleteUser(user: User) {
    this.userHttp.delteUser(user.id.toString()).subscribe(() => {
      this.loadUserInCache();
      console.info("delete one user")
      this.unslecteUser();
    })
  }


  selectUser(user: User | null) {
    if (user == null) {
      this.unslecteUser();
    } else {
      var sub = this.userHttp.getUser(user.id.toString()).subscribe(fromApi => {
        this.selectedUser.next(fromApi);
        sub.unsubscribe();
      })
    }
  }
  unslecteUser() {
    this.selectUser(null);
  }

  editAssignemnts(id: number, newUser: User) {
    this.userHttp.updateUser(id.toString(), newUser).subscribe(() => {

      this.loadUserInCache();
      console.info("edit one user")
    })
  }
}
